pub struct Session { /* private fields */ }Expand description
A RoQ session.
Implementations
Sourceimpl Session
impl Session
Sourcepub fn new(conn: Connection) -> Self
pub fn new(conn: Connection) -> Self
Creates a new session, based on an existing Connection.
Sourcepub async fn new_send_flow(&self, id: VarInt) -> Result<SendFlow>
pub async fn new_send_flow(&self, id: VarInt) -> Result<SendFlow>
Create a new SendFlow.
Sourcepub async fn new_receive_flow(&self, id: VarInt) -> Result<ReceiveFlow>
pub async fn new_receive_flow(&self, id: VarInt) -> Result<ReceiveFlow>
Creates a new receive flow.
If a message has already been received on a flow will return that flow.